# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageStatisticsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkAdaptiveHistogramEqualizationImageFilterPython
else:
    import _itkAdaptiveHistogramEqualizationImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkOffsetPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkBoxImageFilterPython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkNeighborhoodPython
class itkAdaptiveEqualizationHistogramFF(object):
    r"""Proxy of C++ itkAdaptiveEqualizationHistogramFF class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AddPixel(self, p):
        r"""
        AddPixel(self, p)

        Parameters
        ----------
        p: float const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_AddPixel(self, p)

    def RemovePixel(self, p):
        r"""
        RemovePixel(self, p)

        Parameters
        ----------
        p: float const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_RemovePixel(self, p)

    def GetValue(self, pixel):
        r"""
        GetValue(self, pixel) -> float

        Parameters
        ----------
        pixel: float const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_GetValue(self, pixel)

    def AddBoundary(self):
        r"""AddBoundary(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_AddBoundary(self)

    def RemoveBoundary(self):
        r"""RemoveBoundary(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_RemoveBoundary(self)

    def SetAlpha(self, alpha):
        r"""
        SetAlpha(self, alpha)

        Parameters
        ----------
        alpha: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_SetAlpha(self, alpha)

    def SetBeta(self, beta):
        r"""
        SetBeta(self, beta)

        Parameters
        ----------
        beta: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_SetBeta(self, beta)

    def SetKernelSize(self, kernelSize):
        r"""
        SetKernelSize(self, kernelSize)

        Parameters
        ----------
        kernelSize: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_SetKernelSize(self, kernelSize)

    def SetMinimum(self, minimum):
        r"""
        SetMinimum(self, minimum)

        Parameters
        ----------
        minimum: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_SetMinimum(self, minimum)

    def SetMaximum(self, maximum):
        r"""
        SetMaximum(self, maximum)

        Parameters
        ----------
        maximum: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_SetMaximum(self, maximum)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkAdaptiveEqualizationHistogramFF
        __init__(self, arg0) -> itkAdaptiveEqualizationHistogramFF

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramFF const &

        """
        _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_swiginit(self, _itkAdaptiveHistogramEqualizationImageFilterPython.new_itkAdaptiveEqualizationHistogramFF(*args))
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveEqualizationHistogramFF

# Register itkAdaptiveEqualizationHistogramFF in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramFF_swigregister(itkAdaptiveEqualizationHistogramFF)
class itkAdaptiveEqualizationHistogramSSSS(object):
    r"""Proxy of C++ itkAdaptiveEqualizationHistogramSSSS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AddPixel(self, p):
        r"""
        AddPixel(self, p)

        Parameters
        ----------
        p: short const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_AddPixel(self, p)

    def RemovePixel(self, p):
        r"""
        RemovePixel(self, p)

        Parameters
        ----------
        p: short const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_RemovePixel(self, p)

    def GetValue(self, pixel):
        r"""
        GetValue(self, pixel) -> short

        Parameters
        ----------
        pixel: short const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_GetValue(self, pixel)

    def AddBoundary(self):
        r"""AddBoundary(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_AddBoundary(self)

    def RemoveBoundary(self):
        r"""RemoveBoundary(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_RemoveBoundary(self)

    def SetAlpha(self, alpha):
        r"""
        SetAlpha(self, alpha)

        Parameters
        ----------
        alpha: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_SetAlpha(self, alpha)

    def SetBeta(self, beta):
        r"""
        SetBeta(self, beta)

        Parameters
        ----------
        beta: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_SetBeta(self, beta)

    def SetKernelSize(self, kernelSize):
        r"""
        SetKernelSize(self, kernelSize)

        Parameters
        ----------
        kernelSize: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_SetKernelSize(self, kernelSize)

    def SetMinimum(self, minimum):
        r"""
        SetMinimum(self, minimum)

        Parameters
        ----------
        minimum: short

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_SetMinimum(self, minimum)

    def SetMaximum(self, maximum):
        r"""
        SetMaximum(self, maximum)

        Parameters
        ----------
        maximum: short

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_SetMaximum(self, maximum)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkAdaptiveEqualizationHistogramSSSS
        __init__(self, arg0) -> itkAdaptiveEqualizationHistogramSSSS

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramSSSS const &

        """
        _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_swiginit(self, _itkAdaptiveHistogramEqualizationImageFilterPython.new_itkAdaptiveEqualizationHistogramSSSS(*args))
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveEqualizationHistogramSSSS

# Register itkAdaptiveEqualizationHistogramSSSS in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramSSSS_swigregister(itkAdaptiveEqualizationHistogramSSSS)
class itkAdaptiveEqualizationHistogramUCUC(object):
    r"""Proxy of C++ itkAdaptiveEqualizationHistogramUCUC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AddPixel(self, p):
        r"""
        AddPixel(self, p)

        Parameters
        ----------
        p: unsigned char const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_AddPixel(self, p)

    def RemovePixel(self, p):
        r"""
        RemovePixel(self, p)

        Parameters
        ----------
        p: unsigned char const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_RemovePixel(self, p)

    def GetValue(self, pixel):
        r"""
        GetValue(self, pixel) -> unsigned char

        Parameters
        ----------
        pixel: unsigned char const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_GetValue(self, pixel)

    def AddBoundary(self):
        r"""AddBoundary(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_AddBoundary(self)

    def RemoveBoundary(self):
        r"""RemoveBoundary(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_RemoveBoundary(self)

    def SetAlpha(self, alpha):
        r"""
        SetAlpha(self, alpha)

        Parameters
        ----------
        alpha: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_SetAlpha(self, alpha)

    def SetBeta(self, beta):
        r"""
        SetBeta(self, beta)

        Parameters
        ----------
        beta: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_SetBeta(self, beta)

    def SetKernelSize(self, kernelSize):
        r"""
        SetKernelSize(self, kernelSize)

        Parameters
        ----------
        kernelSize: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_SetKernelSize(self, kernelSize)

    def SetMinimum(self, minimum):
        r"""
        SetMinimum(self, minimum)

        Parameters
        ----------
        minimum: unsigned char

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_SetMinimum(self, minimum)

    def SetMaximum(self, maximum):
        r"""
        SetMaximum(self, maximum)

        Parameters
        ----------
        maximum: unsigned char

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_SetMaximum(self, maximum)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkAdaptiveEqualizationHistogramUCUC
        __init__(self, arg0) -> itkAdaptiveEqualizationHistogramUCUC

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramUCUC const &

        """
        _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_swiginit(self, _itkAdaptiveHistogramEqualizationImageFilterPython.new_itkAdaptiveEqualizationHistogramUCUC(*args))
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveEqualizationHistogramUCUC

# Register itkAdaptiveEqualizationHistogramUCUC in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveEqualizationHistogramUCUC_swigregister(itkAdaptiveEqualizationHistogramUCUC)

def itkKernelImageFilterIF2IF2Neighborhood_New():
    return itkKernelImageFilterIF2IF2Neighborhood.New()

class itkKernelImageFilterIF2IF2Neighborhood(itk.itkBoxImageFilterPython.itkBoxImageFilterIF2IF2):
    r"""Proxy of C++ itkKernelImageFilterIF2IF2Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKernelImageFilterIF2IF2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF2IF2Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKernelImageFilterIF2IF2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF2IF2Neighborhood_Clone(self)

    def SetKernel(self, kernel):
        r"""
        SetKernel(self, kernel)

        Parameters
        ----------
        kernel: itkNeighborhoodB2 const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF2IF2Neighborhood_SetKernel(self, kernel)

    def GetKernel(self):
        r"""GetKernel(self) -> itkNeighborhoodB2"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF2IF2Neighborhood_GetKernel(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, radius)

        Parameters
        ----------
        radius: itkSize2 const &

        SetRadius(self, radius)

        Parameters
        ----------
        radius: unsigned long const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF2IF2Neighborhood_SetRadius(self, *args)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkKernelImageFilterIF2IF2Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKernelImageFilterIF2IF2Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF2IF2Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKernelImageFilterIF2IF2Neighborhood

        Create a new object of the class itkKernelImageFilterIF2IF2Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKernelImageFilterIF2IF2Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKernelImageFilterIF2IF2Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKernelImageFilterIF2IF2Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKernelImageFilterIF2IF2Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF2IF2Neighborhood_swigregister(itkKernelImageFilterIF2IF2Neighborhood)

def itkKernelImageFilterIF3IF3Neighborhood_New():
    return itkKernelImageFilterIF3IF3Neighborhood.New()

class itkKernelImageFilterIF3IF3Neighborhood(itk.itkBoxImageFilterPython.itkBoxImageFilterIF3IF3):
    r"""Proxy of C++ itkKernelImageFilterIF3IF3Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKernelImageFilterIF3IF3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF3IF3Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKernelImageFilterIF3IF3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF3IF3Neighborhood_Clone(self)

    def SetKernel(self, kernel):
        r"""
        SetKernel(self, kernel)

        Parameters
        ----------
        kernel: itkNeighborhoodB3 const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF3IF3Neighborhood_SetKernel(self, kernel)

    def GetKernel(self):
        r"""GetKernel(self) -> itkNeighborhoodB3"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF3IF3Neighborhood_GetKernel(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, radius)

        Parameters
        ----------
        radius: itkSize3 const &

        SetRadius(self, radius)

        Parameters
        ----------
        radius: unsigned long const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF3IF3Neighborhood_SetRadius(self, *args)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkKernelImageFilterIF3IF3Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKernelImageFilterIF3IF3Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF3IF3Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKernelImageFilterIF3IF3Neighborhood

        Create a new object of the class itkKernelImageFilterIF3IF3Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKernelImageFilterIF3IF3Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKernelImageFilterIF3IF3Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKernelImageFilterIF3IF3Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKernelImageFilterIF3IF3Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIF3IF3Neighborhood_swigregister(itkKernelImageFilterIF3IF3Neighborhood)

def itkKernelImageFilterISS2ISS2Neighborhood_New():
    return itkKernelImageFilterISS2ISS2Neighborhood.New()

class itkKernelImageFilterISS2ISS2Neighborhood(itk.itkBoxImageFilterPython.itkBoxImageFilterISS2ISS2):
    r"""Proxy of C++ itkKernelImageFilterISS2ISS2Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKernelImageFilterISS2ISS2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS2ISS2Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKernelImageFilterISS2ISS2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS2ISS2Neighborhood_Clone(self)

    def SetKernel(self, kernel):
        r"""
        SetKernel(self, kernel)

        Parameters
        ----------
        kernel: itkNeighborhoodB2 const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS2ISS2Neighborhood_SetKernel(self, kernel)

    def GetKernel(self):
        r"""GetKernel(self) -> itkNeighborhoodB2"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS2ISS2Neighborhood_GetKernel(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, radius)

        Parameters
        ----------
        radius: itkSize2 const &

        SetRadius(self, radius)

        Parameters
        ----------
        radius: unsigned long const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS2ISS2Neighborhood_SetRadius(self, *args)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkKernelImageFilterISS2ISS2Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKernelImageFilterISS2ISS2Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS2ISS2Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKernelImageFilterISS2ISS2Neighborhood

        Create a new object of the class itkKernelImageFilterISS2ISS2Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKernelImageFilterISS2ISS2Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKernelImageFilterISS2ISS2Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKernelImageFilterISS2ISS2Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKernelImageFilterISS2ISS2Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS2ISS2Neighborhood_swigregister(itkKernelImageFilterISS2ISS2Neighborhood)

def itkKernelImageFilterISS3ISS3Neighborhood_New():
    return itkKernelImageFilterISS3ISS3Neighborhood.New()

class itkKernelImageFilterISS3ISS3Neighborhood(itk.itkBoxImageFilterPython.itkBoxImageFilterISS3ISS3):
    r"""Proxy of C++ itkKernelImageFilterISS3ISS3Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKernelImageFilterISS3ISS3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS3ISS3Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKernelImageFilterISS3ISS3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS3ISS3Neighborhood_Clone(self)

    def SetKernel(self, kernel):
        r"""
        SetKernel(self, kernel)

        Parameters
        ----------
        kernel: itkNeighborhoodB3 const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS3ISS3Neighborhood_SetKernel(self, kernel)

    def GetKernel(self):
        r"""GetKernel(self) -> itkNeighborhoodB3"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS3ISS3Neighborhood_GetKernel(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, radius)

        Parameters
        ----------
        radius: itkSize3 const &

        SetRadius(self, radius)

        Parameters
        ----------
        radius: unsigned long const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS3ISS3Neighborhood_SetRadius(self, *args)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkKernelImageFilterISS3ISS3Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKernelImageFilterISS3ISS3Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS3ISS3Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKernelImageFilterISS3ISS3Neighborhood

        Create a new object of the class itkKernelImageFilterISS3ISS3Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKernelImageFilterISS3ISS3Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKernelImageFilterISS3ISS3Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKernelImageFilterISS3ISS3Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKernelImageFilterISS3ISS3Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterISS3ISS3Neighborhood_swigregister(itkKernelImageFilterISS3ISS3Neighborhood)

def itkKernelImageFilterIUC2IUC2Neighborhood_New():
    return itkKernelImageFilterIUC2IUC2Neighborhood.New()

class itkKernelImageFilterIUC2IUC2Neighborhood(itk.itkBoxImageFilterPython.itkBoxImageFilterIUC2IUC2):
    r"""Proxy of C++ itkKernelImageFilterIUC2IUC2Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKernelImageFilterIUC2IUC2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC2IUC2Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKernelImageFilterIUC2IUC2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC2IUC2Neighborhood_Clone(self)

    def SetKernel(self, kernel):
        r"""
        SetKernel(self, kernel)

        Parameters
        ----------
        kernel: itkNeighborhoodB2 const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC2IUC2Neighborhood_SetKernel(self, kernel)

    def GetKernel(self):
        r"""GetKernel(self) -> itkNeighborhoodB2"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC2IUC2Neighborhood_GetKernel(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, radius)

        Parameters
        ----------
        radius: itkSize2 const &

        SetRadius(self, radius)

        Parameters
        ----------
        radius: unsigned long const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC2IUC2Neighborhood_SetRadius(self, *args)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkKernelImageFilterIUC2IUC2Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKernelImageFilterIUC2IUC2Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC2IUC2Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKernelImageFilterIUC2IUC2Neighborhood

        Create a new object of the class itkKernelImageFilterIUC2IUC2Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKernelImageFilterIUC2IUC2Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKernelImageFilterIUC2IUC2Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKernelImageFilterIUC2IUC2Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKernelImageFilterIUC2IUC2Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC2IUC2Neighborhood_swigregister(itkKernelImageFilterIUC2IUC2Neighborhood)

def itkKernelImageFilterIUC3IUC3Neighborhood_New():
    return itkKernelImageFilterIUC3IUC3Neighborhood.New()

class itkKernelImageFilterIUC3IUC3Neighborhood(itk.itkBoxImageFilterPython.itkBoxImageFilterIUC3IUC3):
    r"""Proxy of C++ itkKernelImageFilterIUC3IUC3Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkKernelImageFilterIUC3IUC3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC3IUC3Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkKernelImageFilterIUC3IUC3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC3IUC3Neighborhood_Clone(self)

    def SetKernel(self, kernel):
        r"""
        SetKernel(self, kernel)

        Parameters
        ----------
        kernel: itkNeighborhoodB3 const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC3IUC3Neighborhood_SetKernel(self, kernel)

    def GetKernel(self):
        r"""GetKernel(self) -> itkNeighborhoodB3"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC3IUC3Neighborhood_GetKernel(self)

    def SetRadius(self, *args):
        r"""
        SetRadius(self, radius)

        Parameters
        ----------
        radius: itkSize3 const &

        SetRadius(self, radius)

        Parameters
        ----------
        radius: unsigned long const &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC3IUC3Neighborhood_SetRadius(self, *args)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkKernelImageFilterIUC3IUC3Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkKernelImageFilterIUC3IUC3Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC3IUC3Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkKernelImageFilterIUC3IUC3Neighborhood

        Create a new object of the class itkKernelImageFilterIUC3IUC3Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkKernelImageFilterIUC3IUC3Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkKernelImageFilterIUC3IUC3Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkKernelImageFilterIUC3IUC3Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkKernelImageFilterIUC3IUC3Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkKernelImageFilterIUC3IUC3Neighborhood_swigregister(itkKernelImageFilterIUC3IUC3Neighborhood)

def itkMovingHistogramImageFilterBaseIF2IF2Neighborhood_New():
    return itkMovingHistogramImageFilterBaseIF2IF2Neighborhood.New()

class itkMovingHistogramImageFilterBaseIF2IF2Neighborhood(itkKernelImageFilterIF2IF2Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterBaseIF2IF2Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterBaseIF2IF2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF2IF2Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterBaseIF2IF2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF2IF2Neighborhood_Clone(self)

    def GetPixelsPerTranslation(self):
        r"""GetPixelsPerTranslation(self) -> unsigned long"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF2IF2Neighborhood_GetPixelsPerTranslation(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterBaseIF2IF2Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterBaseIF2IF2Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF2IF2Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterBaseIF2IF2Neighborhood

        Create a new object of the class itkMovingHistogramImageFilterBaseIF2IF2Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterBaseIF2IF2Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterBaseIF2IF2Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterBaseIF2IF2Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterBaseIF2IF2Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF2IF2Neighborhood_swigregister(itkMovingHistogramImageFilterBaseIF2IF2Neighborhood)

def itkMovingHistogramImageFilterBaseIF3IF3Neighborhood_New():
    return itkMovingHistogramImageFilterBaseIF3IF3Neighborhood.New()

class itkMovingHistogramImageFilterBaseIF3IF3Neighborhood(itkKernelImageFilterIF3IF3Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterBaseIF3IF3Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterBaseIF3IF3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF3IF3Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterBaseIF3IF3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF3IF3Neighborhood_Clone(self)

    def GetPixelsPerTranslation(self):
        r"""GetPixelsPerTranslation(self) -> unsigned long"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF3IF3Neighborhood_GetPixelsPerTranslation(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterBaseIF3IF3Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterBaseIF3IF3Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF3IF3Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterBaseIF3IF3Neighborhood

        Create a new object of the class itkMovingHistogramImageFilterBaseIF3IF3Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterBaseIF3IF3Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterBaseIF3IF3Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterBaseIF3IF3Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterBaseIF3IF3Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIF3IF3Neighborhood_swigregister(itkMovingHistogramImageFilterBaseIF3IF3Neighborhood)

def itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood_New():
    return itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood.New()

class itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood(itkKernelImageFilterISS2ISS2Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood_Clone(self)

    def GetPixelsPerTranslation(self):
        r"""GetPixelsPerTranslation(self) -> unsigned long"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood_GetPixelsPerTranslation(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood

        Create a new object of the class itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood_swigregister(itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood)

def itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood_New():
    return itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood.New()

class itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood(itkKernelImageFilterISS3ISS3Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood_Clone(self)

    def GetPixelsPerTranslation(self):
        r"""GetPixelsPerTranslation(self) -> unsigned long"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood_GetPixelsPerTranslation(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood

        Create a new object of the class itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood_swigregister(itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood)

def itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood_New():
    return itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood.New()

class itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood(itkKernelImageFilterIUC2IUC2Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood_Clone(self)

    def GetPixelsPerTranslation(self):
        r"""GetPixelsPerTranslation(self) -> unsigned long"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood_GetPixelsPerTranslation(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood

        Create a new object of the class itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood_swigregister(itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood)

def itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood_New():
    return itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood.New()

class itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood(itkKernelImageFilterIUC3IUC3Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood_Clone(self)

    def GetPixelsPerTranslation(self):
        r"""GetPixelsPerTranslation(self) -> unsigned long"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood_GetPixelsPerTranslation(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood

        Create a new object of the class itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood_swigregister(itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood)

def itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE_New():
    return itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE.New()

class itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE(itkMovingHistogramImageFilterBaseIF2IF2Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE_Clone(self)

    def ConfigureHistogram(self, arg0):
        r"""
        ConfigureHistogram(self, arg0)

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramFF &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE_ConfigureHistogram(self, arg0)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE

        Create a new object of the class itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE_swigregister(itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE)

def itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE_New():
    return itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE.New()

class itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE(itkMovingHistogramImageFilterBaseIF3IF3Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE_Clone(self)

    def ConfigureHistogram(self, arg0):
        r"""
        ConfigureHistogram(self, arg0)

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramFF &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE_ConfigureHistogram(self, arg0)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE

        Create a new object of the class itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE_swigregister(itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE)

def itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE_New():
    return itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE.New()

class itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE(itkMovingHistogramImageFilterBaseISS2ISS2Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE_Clone(self)

    def ConfigureHistogram(self, arg0):
        r"""
        ConfigureHistogram(self, arg0)

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramSSSS &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE_ConfigureHistogram(self, arg0)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE

        Create a new object of the class itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE_swigregister(itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE)

def itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE_New():
    return itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE.New()

class itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE(itkMovingHistogramImageFilterBaseISS3ISS3Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE_Clone(self)

    def ConfigureHistogram(self, arg0):
        r"""
        ConfigureHistogram(self, arg0)

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramSSSS &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE_ConfigureHistogram(self, arg0)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE

        Create a new object of the class itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE_swigregister(itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE)

def itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE_New():
    return itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE.New()

class itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE(itkMovingHistogramImageFilterBaseIUC2IUC2Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE_Clone(self)

    def ConfigureHistogram(self, arg0):
        r"""
        ConfigureHistogram(self, arg0)

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramUCUC &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE_ConfigureHistogram(self, arg0)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE

        Create a new object of the class itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE_swigregister(itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE)

def itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE_New():
    return itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE.New()

class itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE(itkMovingHistogramImageFilterBaseIUC3IUC3Neighborhood):
    r"""Proxy of C++ itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE_Clone(self)

    def ConfigureHistogram(self, arg0):
        r"""
        ConfigureHistogram(self, arg0)

        Parameters
        ----------
        arg0: itkAdaptiveEqualizationHistogramUCUC &

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE_ConfigureHistogram(self, arg0)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE

        Create a new object of the class itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE_swigregister(itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE)

def itkAdaptiveHistogramEqualizationImageFilterIF2_New():
    return itkAdaptiveHistogramEqualizationImageFilterIF2.New()

class itkAdaptiveHistogramEqualizationImageFilterIF2(itkMovingHistogramImageFilterIF2IF2NeighborhoodAHE):
    r"""Proxy of C++ itkAdaptiveHistogramEqualizationImageFilterIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkAdaptiveHistogramEqualizationImageFilterIF2_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkAdaptiveHistogramEqualizationImageFilterIF2_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_Clone(self)

    def SetAlpha(self, _arg):
        r"""
        SetAlpha(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_SetAlpha(self, _arg)

    def GetAlpha(self):
        r"""GetAlpha(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_GetAlpha(self)

    def SetBeta(self, _arg):
        r"""
        SetBeta(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_SetBeta(self, _arg)

    def GetBeta(self):
        r"""GetBeta(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_GetBeta(self)

    def SetUseLookupTable(self, _arg):
        r"""
        SetUseLookupTable(self, _arg)

        Parameters
        ----------
        _arg: bool const

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_SetUseLookupTable(self, _arg)

    def GetUseLookupTable(self):
        r"""GetUseLookupTable(self) -> bool"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_GetUseLookupTable(self)

    def UseLookupTableOn(self):
        r"""UseLookupTableOn(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_UseLookupTableOn(self)

    def UseLookupTableOff(self):
        r"""UseLookupTableOff(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_UseLookupTableOff(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveHistogramEqualizationImageFilterIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkAdaptiveHistogramEqualizationImageFilterIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkAdaptiveHistogramEqualizationImageFilterIF2

        Create a new object of the class itkAdaptiveHistogramEqualizationImageFilterIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkAdaptiveHistogramEqualizationImageFilterIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkAdaptiveHistogramEqualizationImageFilterIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkAdaptiveHistogramEqualizationImageFilterIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkAdaptiveHistogramEqualizationImageFilterIF2 in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF2_swigregister(itkAdaptiveHistogramEqualizationImageFilterIF2)

def itkAdaptiveHistogramEqualizationImageFilterIF3_New():
    return itkAdaptiveHistogramEqualizationImageFilterIF3.New()

class itkAdaptiveHistogramEqualizationImageFilterIF3(itkMovingHistogramImageFilterIF3IF3NeighborhoodAHE):
    r"""Proxy of C++ itkAdaptiveHistogramEqualizationImageFilterIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkAdaptiveHistogramEqualizationImageFilterIF3_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkAdaptiveHistogramEqualizationImageFilterIF3_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_Clone(self)

    def SetAlpha(self, _arg):
        r"""
        SetAlpha(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_SetAlpha(self, _arg)

    def GetAlpha(self):
        r"""GetAlpha(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_GetAlpha(self)

    def SetBeta(self, _arg):
        r"""
        SetBeta(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_SetBeta(self, _arg)

    def GetBeta(self):
        r"""GetBeta(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_GetBeta(self)

    def SetUseLookupTable(self, _arg):
        r"""
        SetUseLookupTable(self, _arg)

        Parameters
        ----------
        _arg: bool const

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_SetUseLookupTable(self, _arg)

    def GetUseLookupTable(self):
        r"""GetUseLookupTable(self) -> bool"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_GetUseLookupTable(self)

    def UseLookupTableOn(self):
        r"""UseLookupTableOn(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_UseLookupTableOn(self)

    def UseLookupTableOff(self):
        r"""UseLookupTableOff(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_UseLookupTableOff(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveHistogramEqualizationImageFilterIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkAdaptiveHistogramEqualizationImageFilterIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkAdaptiveHistogramEqualizationImageFilterIF3

        Create a new object of the class itkAdaptiveHistogramEqualizationImageFilterIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkAdaptiveHistogramEqualizationImageFilterIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkAdaptiveHistogramEqualizationImageFilterIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkAdaptiveHistogramEqualizationImageFilterIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkAdaptiveHistogramEqualizationImageFilterIF3 in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIF3_swigregister(itkAdaptiveHistogramEqualizationImageFilterIF3)

def itkAdaptiveHistogramEqualizationImageFilterISS2_New():
    return itkAdaptiveHistogramEqualizationImageFilterISS2.New()

class itkAdaptiveHistogramEqualizationImageFilterISS2(itkMovingHistogramImageFilterISS2ISS2NeighborhoodAHE):
    r"""Proxy of C++ itkAdaptiveHistogramEqualizationImageFilterISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkAdaptiveHistogramEqualizationImageFilterISS2_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkAdaptiveHistogramEqualizationImageFilterISS2_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_Clone(self)

    def SetAlpha(self, _arg):
        r"""
        SetAlpha(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_SetAlpha(self, _arg)

    def GetAlpha(self):
        r"""GetAlpha(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_GetAlpha(self)

    def SetBeta(self, _arg):
        r"""
        SetBeta(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_SetBeta(self, _arg)

    def GetBeta(self):
        r"""GetBeta(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_GetBeta(self)

    def SetUseLookupTable(self, _arg):
        r"""
        SetUseLookupTable(self, _arg)

        Parameters
        ----------
        _arg: bool const

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_SetUseLookupTable(self, _arg)

    def GetUseLookupTable(self):
        r"""GetUseLookupTable(self) -> bool"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_GetUseLookupTable(self)

    def UseLookupTableOn(self):
        r"""UseLookupTableOn(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_UseLookupTableOn(self)

    def UseLookupTableOff(self):
        r"""UseLookupTableOff(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_UseLookupTableOff(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveHistogramEqualizationImageFilterISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkAdaptiveHistogramEqualizationImageFilterISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkAdaptiveHistogramEqualizationImageFilterISS2

        Create a new object of the class itkAdaptiveHistogramEqualizationImageFilterISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkAdaptiveHistogramEqualizationImageFilterISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkAdaptiveHistogramEqualizationImageFilterISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkAdaptiveHistogramEqualizationImageFilterISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkAdaptiveHistogramEqualizationImageFilterISS2 in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS2_swigregister(itkAdaptiveHistogramEqualizationImageFilterISS2)

def itkAdaptiveHistogramEqualizationImageFilterISS3_New():
    return itkAdaptiveHistogramEqualizationImageFilterISS3.New()

class itkAdaptiveHistogramEqualizationImageFilterISS3(itkMovingHistogramImageFilterISS3ISS3NeighborhoodAHE):
    r"""Proxy of C++ itkAdaptiveHistogramEqualizationImageFilterISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkAdaptiveHistogramEqualizationImageFilterISS3_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkAdaptiveHistogramEqualizationImageFilterISS3_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_Clone(self)

    def SetAlpha(self, _arg):
        r"""
        SetAlpha(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_SetAlpha(self, _arg)

    def GetAlpha(self):
        r"""GetAlpha(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_GetAlpha(self)

    def SetBeta(self, _arg):
        r"""
        SetBeta(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_SetBeta(self, _arg)

    def GetBeta(self):
        r"""GetBeta(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_GetBeta(self)

    def SetUseLookupTable(self, _arg):
        r"""
        SetUseLookupTable(self, _arg)

        Parameters
        ----------
        _arg: bool const

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_SetUseLookupTable(self, _arg)

    def GetUseLookupTable(self):
        r"""GetUseLookupTable(self) -> bool"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_GetUseLookupTable(self)

    def UseLookupTableOn(self):
        r"""UseLookupTableOn(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_UseLookupTableOn(self)

    def UseLookupTableOff(self):
        r"""UseLookupTableOff(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_UseLookupTableOff(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveHistogramEqualizationImageFilterISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkAdaptiveHistogramEqualizationImageFilterISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkAdaptiveHistogramEqualizationImageFilterISS3

        Create a new object of the class itkAdaptiveHistogramEqualizationImageFilterISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkAdaptiveHistogramEqualizationImageFilterISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkAdaptiveHistogramEqualizationImageFilterISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkAdaptiveHistogramEqualizationImageFilterISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkAdaptiveHistogramEqualizationImageFilterISS3 in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterISS3_swigregister(itkAdaptiveHistogramEqualizationImageFilterISS3)

def itkAdaptiveHistogramEqualizationImageFilterIUC2_New():
    return itkAdaptiveHistogramEqualizationImageFilterIUC2.New()

class itkAdaptiveHistogramEqualizationImageFilterIUC2(itkMovingHistogramImageFilterIUC2IUC2NeighborhoodAHE):
    r"""Proxy of C++ itkAdaptiveHistogramEqualizationImageFilterIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkAdaptiveHistogramEqualizationImageFilterIUC2_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkAdaptiveHistogramEqualizationImageFilterIUC2_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_Clone(self)

    def SetAlpha(self, _arg):
        r"""
        SetAlpha(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_SetAlpha(self, _arg)

    def GetAlpha(self):
        r"""GetAlpha(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_GetAlpha(self)

    def SetBeta(self, _arg):
        r"""
        SetBeta(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_SetBeta(self, _arg)

    def GetBeta(self):
        r"""GetBeta(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_GetBeta(self)

    def SetUseLookupTable(self, _arg):
        r"""
        SetUseLookupTable(self, _arg)

        Parameters
        ----------
        _arg: bool const

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_SetUseLookupTable(self, _arg)

    def GetUseLookupTable(self):
        r"""GetUseLookupTable(self) -> bool"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_GetUseLookupTable(self)

    def UseLookupTableOn(self):
        r"""UseLookupTableOn(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_UseLookupTableOn(self)

    def UseLookupTableOff(self):
        r"""UseLookupTableOff(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_UseLookupTableOff(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveHistogramEqualizationImageFilterIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkAdaptiveHistogramEqualizationImageFilterIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkAdaptiveHistogramEqualizationImageFilterIUC2

        Create a new object of the class itkAdaptiveHistogramEqualizationImageFilterIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkAdaptiveHistogramEqualizationImageFilterIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkAdaptiveHistogramEqualizationImageFilterIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkAdaptiveHistogramEqualizationImageFilterIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkAdaptiveHistogramEqualizationImageFilterIUC2 in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC2_swigregister(itkAdaptiveHistogramEqualizationImageFilterIUC2)

def itkAdaptiveHistogramEqualizationImageFilterIUC3_New():
    return itkAdaptiveHistogramEqualizationImageFilterIUC3.New()

class itkAdaptiveHistogramEqualizationImageFilterIUC3(itkMovingHistogramImageFilterIUC3IUC3NeighborhoodAHE):
    r"""Proxy of C++ itkAdaptiveHistogramEqualizationImageFilterIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkAdaptiveHistogramEqualizationImageFilterIUC3_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkAdaptiveHistogramEqualizationImageFilterIUC3_Pointer"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_Clone(self)

    def SetAlpha(self, _arg):
        r"""
        SetAlpha(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_SetAlpha(self, _arg)

    def GetAlpha(self):
        r"""GetAlpha(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_GetAlpha(self)

    def SetBeta(self, _arg):
        r"""
        SetBeta(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_SetBeta(self, _arg)

    def GetBeta(self):
        r"""GetBeta(self) -> float"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_GetBeta(self)

    def SetUseLookupTable(self, _arg):
        r"""
        SetUseLookupTable(self, _arg)

        Parameters
        ----------
        _arg: bool const

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_SetUseLookupTable(self, _arg)

    def GetUseLookupTable(self):
        r"""GetUseLookupTable(self) -> bool"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_GetUseLookupTable(self)

    def UseLookupTableOn(self):
        r"""UseLookupTableOn(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_UseLookupTableOn(self)

    def UseLookupTableOff(self):
        r"""UseLookupTableOff(self)"""
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_UseLookupTableOff(self)
    __swig_destroy__ = _itkAdaptiveHistogramEqualizationImageFilterPython.delete_itkAdaptiveHistogramEqualizationImageFilterIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkAdaptiveHistogramEqualizationImageFilterIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkAdaptiveHistogramEqualizationImageFilterIUC3

        Create a new object of the class itkAdaptiveHistogramEqualizationImageFilterIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkAdaptiveHistogramEqualizationImageFilterIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkAdaptiveHistogramEqualizationImageFilterIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkAdaptiveHistogramEqualizationImageFilterIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkAdaptiveHistogramEqualizationImageFilterIUC3 in _itkAdaptiveHistogramEqualizationImageFilterPython:
_itkAdaptiveHistogramEqualizationImageFilterPython.itkAdaptiveHistogramEqualizationImageFilterIUC3_swigregister(itkAdaptiveHistogramEqualizationImageFilterIUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def moving_histogram_image_filter(*args: itkt.ImageLike,  kernel=..., radius: Union[int, int, Sequence[int], Sequence[int]]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for MovingHistogramImageFilter"""
    import itk

    kwarg_typehints = { 'kernel':kernel,'radius':radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.MovingHistogramImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def moving_histogram_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageStatistics.MovingHistogramImageFilter
    moving_histogram_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    moving_histogram_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def kernel_image_filter(*args: itkt.ImageLike,  kernel=..., radius: Union[int, int, Sequence[int], Sequence[int]]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for KernelImageFilter"""
    import itk

    kwarg_typehints = { 'kernel':kernel,'radius':radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.KernelImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def kernel_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageStatistics.KernelImageFilter
    kernel_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    kernel_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def moving_histogram_image_filter_base(*args: itkt.ImageLike,  kernel=..., radius: Union[int, Sequence[int], int, Sequence[int]]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for MovingHistogramImageFilterBase"""
    import itk

    kwarg_typehints = { 'kernel':kernel,'radius':radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.MovingHistogramImageFilterBase.New(*args, **kwargs)

    return instance.__internal_call__()

def moving_histogram_image_filter_base_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageStatistics.MovingHistogramImageFilterBase
    moving_histogram_image_filter_base.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    moving_histogram_image_filter_base.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def adaptive_histogram_equalization_image_filter(*args: itkt.ImageLike,  alpha: float=..., beta: float=..., use_lookup_table: bool=..., kernel=..., radius: Union[int, Sequence[int], int, Sequence[int]]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for AdaptiveHistogramEqualizationImageFilter"""
    import itk

    kwarg_typehints = { 'alpha':alpha,'beta':beta,'use_lookup_table':use_lookup_table,'kernel':kernel,'radius':radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.AdaptiveHistogramEqualizationImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def adaptive_histogram_equalization_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageStatistics.AdaptiveHistogramEqualizationImageFilter
    adaptive_histogram_equalization_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    adaptive_histogram_equalization_image_filter.__doc__ = filter_object.__doc__



